/* vi:set et ai sw=2 sts=2 ts=2: */
/*-
 * Copyright (c) 2006-2009 Jannis Pohlmann <jannis@xfce.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General
 * Public License along with this library; if not, write to the
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifndef __GARCON_H__
#define __GARCON_H__

#include <gio/gio.h>

#define _GARCON_INSIDE_GARCON_H

#include <garcon/garcon-config.h>
#include <garcon/garcon-menu-directory.h>
#include <garcon/garcon-menu-element.h>
#include <garcon/garcon-environment.h>
#include <garcon/garcon-menu.h>
#include <garcon/garcon-menu-item.h>
#include <garcon/garcon-menu-item-action.h>
#include <garcon/garcon-menu-item-cache.h>
#include <garcon/garcon-menu-item-pool.h>
#include <garcon/garcon-menu-node.h>
#include <garcon/garcon-menu-merger.h>
#include <garcon/garcon-menu-parser.h>
#include <garcon/garcon-menu-separator.h>
#include <garcon/garcon-menu-tree-provider.h>

#undef _GARCON_INSIDE_GARCON_H

#endif /* !__GARCON_H__ */
